@@ -40,7 +40,7 @@ class LidarFrame:
         self.id = frame_id
         self.cameras: pd.Series[Any, LidarCamera] = cameras
         self.images: pd.Series[Any, LidarImage] = pd.Series(dtype=object)
-        self.points: np.ndarray = np.zeros((0, 5), dtype=float)
+        self.points: np.ndarray = np.zeros((0, 6), dtype=float)
         self.radar_points: np.ndarray = np.zeros((0, 3), dtype=float)
         self.colors: np.ndarray = np.zeros((0, 3), dtype=float)
         self.transform = Transform()
@@ -148,6 +148,12 @@ class LidarFrame:
                     [points, np.ones((points.shape[0], 1)) * sensor_id])
             else:
                 points = np.hstack([points, np.zeros((points.shape[0], 1))])
+        if points.shape[1] == 5:
+            if sensor_id != 0:
+                points = np.hstack(
+                    [points, np.ones((points.shape[0], 1)) * sensor_id])
+            else:
+                points = np.hstack([points, np.zeros((points.shape[0], 1))])
         if transform is not None:
             points = transform.apply(points)
 
@@ -206,6 +212,7 @@ class LidarFrame:
                 self.transform @ self.points[:, :3],
                 self.points[:, 3:4],
                 self.points[:, 4:5],
+                self.points[:, 5:6],
             ]
         )
 
@@ -426,7 +433,7 @@ class LidarFrame:
             .to_json(orient="records")
         )
         points_json = pd.DataFrame(
-            self.get_world_points(), columns=["x", "y", "z", "i", "d"]
+            self.get_world_points(), columns=["x", "y", "z", "i", "d", "t"]
         ).to_json(double_precision=4, orient="records", date_format=None)
 
         colors_json = pd.Series(self.colors.reshape(-1).astype(np.uint32)).to_json(
