@@ -87,7 +87,7 @@ def get_s3_etag(bucket, key):
 def get_signed_url(bucket: str, path: str) -> str:
     s3 = get_s3_client()
     signed_url = s3.generate_presigned_url(
-        "get_object", Params={"Bucket": bucket, "Key": f"{path}/scene.json"}
+        "get_object", Params={"Bucket": bucket, "Key": path}
     )
     return signed_url
 
