@@ -16,6 +16,7 @@ from .frame import LidarFrame
 from .connectors import Importer
 from .transform import Transform
 from .helper import s3_smart_upload, get_signed_url
+from .protobuf_helper import create_scene_from_protobufs
 
 UPLOAD_POOL_SIZE = 8
 
@@ -39,6 +40,19 @@ class LidarScene:
         self.base_url = None
         self.scale_file_attachments = None
 
+    @classmethod
+    def from_protobufs(cls, protobufs: List[str]):
+        """
+        Create a LidarScene object from a list of protobuf files
+        :param protobufs: Filepaths to the .pb files, one per frame
+        :type protobufs: List[str]
+
+        Note: this function expects a point cloud in ego coordinates
+
+        Returns: LidarScene
+        """
+        return create_scene_from_protobufs(cls(), protobufs)
+
     def get_camera(self, camera_id=None, index: int = None) -> LidarCamera:
         """Get a camera by id (or index) or create one if it does not exist
 
