@@ -102,7 +102,9 @@ class LidarAnnotationTask(Task):
             ]
         )
 
-    def publish(self, task_type: TaskType = TaskType.LidarAnnotation):
+    def publish(
+        self, task_type: TaskType = TaskType.LidarAnnotation, verbose: bool = True
+    ):
         """Publish/create a task, request Scale API with the LidarAnnotation data
 
         :param task_type: Task type to create, default ``lidarannotation``
@@ -112,7 +114,8 @@ class LidarAnnotationTask(Task):
 
         """
         task = self._client.create_task(task_type, **self.as_dict())
-        print("Task created: %s" % task)
+        if verbose:
+            print("Task created: %s" % task)
         return task
 
 
@@ -180,7 +183,9 @@ class LidarTopDownTask(Task):
         task = get_api_client().fetch_task(task_id)
         return LidarTopDownTask(task.param_dict, task.client)
 
-    def publish(self, task_type: TaskType = TaskType.LidarTopdown):
+    def publish(
+        self, task_type: TaskType = TaskType.LidarTopdown, verbose: bool = True
+    ):
         """Publish/create a task, request Scale API with the LidarTopDown data
 
         :param task_type: Task type to create, default ``lidartopdown``
@@ -190,7 +195,8 @@ class LidarTopDownTask(Task):
 
         """
         task = self._client.create_task(task_type, **self.as_dict())
-        print("Task created: %s" % task)
+        if verbose:
+            print("Task created: %s" % task)
         return task
 
 
@@ -258,7 +264,9 @@ class LidarSegmentationTask(Task):
         task = get_api_client().fetch_task(task_id)
         return LidarSegmentationTask(task.param_dict, task.client)
 
-    def publish(self, task_type: TaskType = TaskType.LidarSegmentation):
+    def publish(
+        self, task_type: TaskType = TaskType.LidarSegmentation, verbose: bool = True
+    ):
         """Publish/create a task, request Scale API with the LidarSegmentation data
 
         :param task_type: Task type to create, default ``lidarsegmentation``
@@ -268,5 +276,6 @@ class LidarSegmentationTask(Task):
 
         """
         task = self._client.create_task(task_type, **self.as_dict())
-        print("Task created: %s" % task)
+        if verbose:
+            print("Task created: %s" % task)
         return task
